clear

**********************************************************************
* RUN Do-File 'Data Reading' 		                                 *
**********************************************************************
quietly do "do_files\Data Reading.do"


**********************************************************************
* RUN Do- File 'variables_analyses_final_outcomes'					 *
**********************************************************************
quietly do "do_files\variables_analyses_final_outcomes.do"


********************************************************************************
*	ANALYSES					   *
********************************************************************************

*	CHARACTERISTICS OF SUBJECTS

tab sex if period==1
* 134 female and 104 male participants (2 no answer)

tab student if period==1
* 97.5% students from University of Cologne

tab econ_student if period==1
* 101 econ students



*****************************************
* SECTION 4.1 MAJORITY RULE INSTABILITY *
*****************************************

		*	MEAN OUTCOME

		sum final_x final_y if treatment==1
		*	x= 41.45	y= 67.23

		sum final_x final_y if treatment==3
		*	x= 46.86	y= 66.59

		sum final_x final_y if treatment==4
		*	x= 45.74	y= 65.35

		sum final_x final_y if treatment==6
		*	x= 49.30	y= 61.79


*** FIGURE 2

foreach x in A B C D E {
capture gen player_`x'="`x'"
}

* Treatment 1
twoway ///
	(scatter m20_fin_y m20_fin_x if period==1 & type==1, msymbol(S) mlcolor(black) mfcolor(gs10%30) msize(medsmall) aspect(0.75)) ///
	(scatter opt_y1 opt_x1 if type==1 & period==1 & groupid==101, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_A) mlabcolor(black) mlabsize(medium) mlabposition(5)) ///
	(scatter opt_y2 opt_x2 if type==2 & period==1 & groupid==101, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_B) mlabcolor(black) mlabsize(medium) mlabposition(7)) ///
	(scatter opt_y3 opt_x3 if type==3 & period==1 & groupid==101, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_C) mlabcolor(black) mlabsize(medium) mlabposition(12)) ///
	(scatter opt_y4 opt_x4 if type==4 & period==1 & groupid==101, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_D) mlabcolor(black) mlabsize(medium) mlabposition(1)) ///
	(scatter opt_y5 opt_x5 if type==5 & period==1 & groupid==101, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_E) mlabcolor(black) mlabsize(medium) mlabposition(3)) ///
	if treatment==1, ///     
		legend(label(1 "Average committee decision in periods 1-20") size(small) order(1) ring(0) bplacement(neast) rows(1)) ///
		title(`"{bf: (A) Core - low conflict}"', size(medium) color(black)) ///
		ytitle("") ///
		yscale(range(0 150)) ylabel(0 (10) 150, labsize(vsmall) grid glwidth(vthin)) ///    
		xscale(range(0 200)) xlabel(0 (10) 200, labsize(vsmall) grid glwidth(vthin)) ///    
		graphregion(color(white) margin(vsmall)) ///
		plotregion(lcolor(black) lwidth(medthick) margin(vsmall)) ///
		note("Average decision: (41.5|67.2)" "Average standard distance deviation: 11.7", size(small)) ///
		name(T1, replace)
	

* Treatment 4
twoway ///
	(scatter m20_fin_y m20_fin_x if period==1 & type==1, msymbol(S) mlcolor(black) mfcolor(gs10%50) msize(medsmall) aspect(0.75)) ///
	(scatter opt_y1 opt_x1 if type==1 & period==1 & groupid==401, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_A) mlabcolor(black) mlabsize(medium) mlabposition(5)) ///
	(scatter opt_y2 opt_x2 if type==2 & period==1 & groupid==401, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_B) mlabcolor(black) mlabsize(medium) mlabposition(7)) ///
	(scatter opt_y3 opt_x3 if type==3 & period==1 & groupid==401, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_C) mlabcolor(black) mlabsize(medium) mlabposition(12)) ///
	(scatter opt_y4 opt_x4 if type==4 & period==1 & groupid==401, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_D) mlabcolor(black) mlabsize(medium) mlabposition(1)) ///
	(scatter opt_y5 opt_x5 if type==5 & period==1 & groupid==401, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_E) mlabcolor(black) mlabsize(medium) mlabposition(3)) ///
	if treatment==4, ///     
		legend(label(1 "Average committee decision in periods 1-20") size(small) order(1) ring(0) bplacement(neast) rows(1)) ///
		title(`"{bf: (B) Empty core - low conflict}"', size(medium) color(black)) ///
		ytitle("") ///
		yscale(range(0 150)) ylabel(0 (10) 150, labsize(vsmall) grid glwidth(vthin)) ///    
		xscale(range(0 200)) xlabel(0 (10) 200, labsize(vsmall) grid glwidth(vthin)) ///    
		graphregion(color(white) margin(vsmall)) ///
		plotregion(lcolor(black) lwidth(medthick) margin(vsmall)) ///
		note("Average decision: (46.9|66.6)" "Average standard distance deviation: 13.9", size(small)) ///
		name(T4, replace)	

graph combine T1 T4, ///
	graphregion(color(white) margin(vsmall)) ///
	note("{it:Note}" "Average standard distance deviation: Value reports the treatment average of the standard distance deviation" "of the 20 outcomes chosen by committees", size(vsmall)) ///
	rows(2) xsize(6) ysize(9)


********************************************************************************
* STANDARD DISTANCE DEVIATION OF 20 GROUP DECISIONS							****
********************************************************************************
 
		bys treatment: sum std_group_final if period==1 & type==1	
		
		permtest2 std_group_final if period==1 & type==1 & (treatment==1 | treatment==4), by(treatment)
		*	Test of hypothesis Ho: std_group_final(treatment==1) == std_group_final(treatment==4) :  p=.34758 (two-tailed)

		
		
********************************************************************************
* 	DISTANCE FROM PREVIOUS RESULT

*	Period one is excluded in all analyses because the status quo in period 1 is
*	point 190|140 at the top right margin of the policy space. A large shift from
*	the status quo to the final result in period 1 is therefore trivial and would
* 	bias the analysis.


* FIGURE 3: Treatment 1 vs. 4
graph bar dist_res_sq_5_mean  if type==2 & marker5==1 & ( treatment==1 | treatment==4), ///
	over(treatment, relabel(1 "Core" 2 "Empty core") label(labsize(small)) gap(0) ) over(per5, relabel(1 `" "{bf: Periods 2-5}" "{it:p}=0.499" "' 2 `" "{bf: Periods 6-10}" "{it:p}=0.025" "' 3 `" "{bf: Periods 11-15}" "{it:p}=0.028" "' 4 `" "{bf: Periods 16-20}" "{it:p}=0.012" "') ) ///
	asyvars bar(1, color(gs6)) bar(2, color(black)) ///
	ytitle("{bf: Mean distance between}" "{bf:decisions and the status quo}", size(medsmall)) ylabel(0 (10) 42.5) ///
	blabel(bar, size(medium) format(%9.1f)) ///
	graphregion(color(white) margin(medium)) ///
	legend(rows(2) label(1 "Core - low conflict		") label(2 "Empty core - low conflict") size(small) ring(0) bplacement(neast)) ///
	note("{it:Notes:}" "Period 1 ommitted" "{it:p}-values from two-tailed Fisher-Pitman permutation tests for two independent samples", size(small))


		sum dist_res_sq if treatment==1 & type==1 & period!=1, detail
		*	Average distance between status quo and final result: 5.97 points
		

		sum dist_res_sq if treatment==4 & type==1 & period!=1, detail
		*	Average distance between status quo and final result: 9.42 points
	

		* SIGNIFICANCE TESTS
		*	Does the average distance between status quo and final result differ between
		*	treatments?

		permtest2 dist_res_sq_20_mean if period==1 & type==1 & (treatment==1 | treatment==4), by(treatment)
		*	Test of hypothesis Ho: dist_res_sq_20_mean(treatment==1) == dist_res_sq_20_mean(treatment==4) :  p=.05533 (two-tailed)
		*	ANSWER: YES!
		
		
		*	DOES BEHAVIOR CHANGE OVER TIME ? - 5-period intervals

		* Treatments 1&4
			sum dist_res_sq_5_mean if treatment==1 & type==1 & period==1
			*	Average distance between status quo and final result: 12.77 points
			sum dist_res_sq_5_mean if treatment==1 & type==1 & period==6
			*	Average distance between status quo and final result: 4.05 points
			sum dist_res_sq_5_mean if treatment==1 & type==1 & period==11
			*	Average distance between status quo and final result: 3.55 points
			sum dist_res_sq_5_mean if treatment==1 & type==1 & period==16
			*	Average distance between status quo and final result: 4.87 points

			sum dist_res_sq_5_mean if treatment==4 & type==1 & period==1
			*	Average distance between status quo and final result: 9.90 points
			sum dist_res_sq_5_mean if treatment==4 & type==1 & period==6
			*	Average distance between status quo and final result: 8.55 points
			sum dist_res_sq_5_mean if treatment==4 & type==1 & period==11
			*	Average distance between status quo and final result: 8.42 points
			sum dist_res_sq_5_mean if treatment==4 & type==1 & period==16
			*	Average distance between status quo and final result: 10.90 points

			permtest2 dist_res_sq_5_mean if period==1 & type==1 & (treatment==1 | treatment==4), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==1) == dist_res_sq_5_mean(treatment==4) :  p=.49914 (two-tailed)
			permtest2 dist_res_sq_5_mean if period==6 & type==1 & (treatment==1 | treatment==4), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==1) == dist_res_sq_5_mean(treatment==4) :  p=.02527 (two-tailed)
			permtest2 dist_res_sq_5_mean if period==11 & type==1 & (treatment==1 | treatment==4), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==1) == dist_res_sq_5_mean(treatment==4) :  p=.0284 (two-tailed)
			permtest2 dist_res_sq_5_mean if period==16 & type==1 & (treatment==1 | treatment==4), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==1) == dist_res_sq_5_mean(treatment==4) :  p=.01232 (two-tailed)


	
*FIGURE 4	
	
* Treatment 3
twoway ///
	(scatter m20_fin_y m20_fin_x if period==1 & type==1, msymbol(S) mlcolor(black) mfcolor(gs10%30) msize(medsmall) aspect(0.75)) ///
	(scatter opt_y1 opt_x1 if type==1 & period==1 & groupid==301, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_A) mlabcolor(black) mlabsize(medium) mlabposition(5)) ///
	(scatter opt_y2 opt_x2 if type==2 & period==1 & groupid==301, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_B) mlabcolor(black) mlabsize(medium) mlabposition(7)) ///
	(scatter opt_y3 opt_x3 if type==3 & period==1 & groupid==301, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_C) mlabcolor(black) mlabsize(medium) mlabposition(12)) ///
	(scatter opt_y4 opt_x4 if type==4 & period==1 & groupid==301, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_D) mlabcolor(black) mlabsize(medium) mlabposition(1)) ///
	(scatter opt_y5 opt_x5 if type==5 & period==1 & groupid==301, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_E) mlabcolor(black) mlabsize(medium) mlabposition(3)) ///
	if treatment==3, ///     
		legend(label(1 "Average committee decision in periods 1-20") size(small) order(1) ring(0) bplacement(neast) rows(1)) ///
		title(`"{bf: (A) Core - high conflict}"', size(medium) color(black)) ///
		ytitle("") ///
		yscale(range(0 150)) ylabel(0 (10) 150, labsize(vsmall) grid glwidth(vthin)) ///    
		xscale(range(0 200)) xlabel(0 (10) 200, labsize(vsmall) grid glwidth(vthin)) ///    
		graphregion(color(white) margin(vsmall)) ///
		plotregion(lcolor(black) lwidth(medthick) margin(vsmall)) ///
		note("Average decision: (46.9|66.6)" "Average standard distance deviation: 40.7", size(small)) ///
		name(T3, replace)
	

* Treatment 6
twoway ///
	(scatter m20_fin_y m20_fin_x if period==1 & type==1, msymbol(S) mlcolor(black) mfcolor(gs10%50) msize(medsmall) aspect(0.75)) ///
	(scatter opt_y1 opt_x1 if type==1 & period==1 & groupid==601, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_A) mlabcolor(black) mlabsize(medium) mlabposition(5)) ///
	(scatter opt_y2 opt_x2 if type==2 & period==1 & groupid==601, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_B) mlabcolor(black) mlabsize(medium) mlabposition(7)) ///
	(scatter opt_y3 opt_x3 if type==3 & period==1 & groupid==601, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_C) mlabcolor(black) mlabsize(medium) mlabposition(12)) ///
	(scatter opt_y4 opt_x4 if type==4 & period==1 & groupid==601, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_D) mlabcolor(black) mlabsize(medium) mlabposition(1)) ///
	(scatter opt_y5 opt_x5 if type==5 & period==1 & groupid==601, mcolor(black) msize(medium) msymbol(lgx) mlabel(player_E) mlabcolor(black) mlabsize(medium) mlabposition(3)) ///
	if treatment==6, ///     
		legend(label(1 "Average committee decision in periods 1-20") size(small) order(1) ring(0) bplacement(neast) rows(1)) ///
		title(`"{bf: (B) Empty core - high conflict}"', size(medium) color(black)) ///
		ytitle("") ///
		yscale(range(0 150)) ylabel(0 (10) 150, labsize(vsmall) grid glwidth(vthin)) ///    
		xscale(range(0 200)) xlabel(0 (10) 200, labsize(vsmall) grid glwidth(vthin)) ///    
		graphregion(color(white) margin(vsmall)) ///
		plotregion(lcolor(black) lwidth(medthick) margin(vsmall)) ///
		note("Average decision: (49.3|61.8)" "Average standard distance deviation: 44.3", size(small)) ///
		name(T6, replace)	

graph combine T3 T6, ///
	graphregion(color(white) margin(vsmall)) ///
	note("{it:Note}" "Average standard distance deviation: Value reports the treatment average of the standard distance deviation" "of the 20 outcomes chosen by committees", size(vsmall)) ///
	rows(2) xsize(6) ysize(9)



********************************************************************************
* STANDARD DISTANCE DEVIATION OF 20 GROUP DECISIONS							****
********************************************************************************
 
		bys treatment: sum std_group_final if period==1 & type==1	
		
		permtest2 std_group_final if period==1 & type==1 & (treatment==3 | treatment==6), by(treatment)
		*	Test of hypothesis Ho: std_group_final(treatment==3) == std_group_final(treatment==6) :  p=.69265 (two-tailed)

		
********************************************************************************
* 	DISTANCE FROM PREVIOUS RESULT

*	Period one is excluded in all analyses because the status quo in period 1 is
*	point 190|140 at the top right margin of the policy space. A large shift from
*	the status quo to the final result in period 1 is therefore trivial and would
* 	bias the analysis.


* FIGURE 5: Treatment 3 vs. 6
graph bar dist_res_sq_5_mean  if type==2 & marker5==1 & ( treatment==3 | treatment==6), ///
	over(treatment, relabel(1 "Core" 2 "Empty core") label(labsize(small)) gap(0) ) over(per5, relabel(1 `" "{bf: Periods 2-5}" "{it:p}=0.713" "' 2 `" "{bf: Periods 6-10}" "{it:p}=0.681" "' 3 `" "{bf: Periods 11-15}" "{it:p}=0.530" "' 4 `" "{bf: Periods 16-20}" "{it:p}=0.678" "') ) ///
	asyvars bar(1, color(gs6)) bar(2, color(black)) ///
	ytitle("{bf: Mean distance between}" "{bf:decisions and the status quo}", size(medsmall)) ylabel(0 (10) 42.5) ///
	blabel(bar, size(medium) format(%9.1f)) ///
	graphregion(color(white) margin(medium)) ///
	legend(rows(2) label(1 "Core - high conflict		") label(2 "Empty core - high conflict") size(small) ring(0) bplacement(neast)) ///
	note("{it:Notes:}" "Period 1 ommitted" "{it:p}-values from two-tailed Fisher-Pitman permutation tests for two independent samples", size(small))


		sum dist_res_sq if treatment==3 & type==1 & period!=1, detail
		*	Average distance between status quo and final result: 24.90 points
		* 	Standard deviation: 37.44

		sum dist_res_sq if treatment==6 & type==1 & period!=1, detail
		*	Average distance between status quo and final result: 27.54 points
		*	Standard deviation: 35.67

		
		* SIGNIFICANCE TESTS
		*	Does the average distance between status quo and final result differ between
		*	treatments?
		
		permtest2 dist_res_sq_20_mean if period==1 & type==1 & (treatment==3 | treatment==6), by(treatment)
		*Test of hypothesis Ho: dist_res_sq_20_mean(treatment==3) == dist_res_sq_20_mean(treatment==6) :  p=.69402 (two-tailed)
		*	ANSWER: NO!


		*	DOES BEHAVIOR CHANGE OVER TIME ? - 5-period intervals

			* Treatments 3&6
			sum dist_res_sq_5_mean if treatment==3 & type==1 & period==1
			*	Average distance between status quo and final result: 34.87 points
			sum dist_res_sq_5_mean if treatment==3 & type==1 & period==6
			*	Average distance between status quo and final result: 22.06 points
			sum dist_res_sq_5_mean if treatment==3 & type==1 & period==11
			*	Average distance between status quo and final result: 22.14 points
			sum dist_res_sq_5_mean if treatment==3 & type==1 & period==16
			*	Average distance between status quo and final result: 22.53 points

			sum dist_res_sq_5_mean if treatment==6 & type==1 & period==1
			*	Average distance between status quo and final result: 38.83 points
			sum dist_res_sq_5_mean if treatment==6 & type==1 & period==6
			*	Average distance between status quo and final result: 18.79 points
			sum dist_res_sq_5_mean if treatment==6 & type==1 & period==11
			*	Average distance between status quo and final result: 27.72 points
			sum dist_res_sq_5_mean if treatment==6 & type==1 & period==16
			*	Average distance between status quo and final result: 27.07 points

			permtest2 dist_res_sq_5_mean if period==1 & type==1 & (treatment==3 | treatment==6), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==3) == dist_res_sq_5_mean(treatment==6) :  p=.71335 (two-tailed)
			permtest2 dist_res_sq_5_mean if period==6 & type==1 & (treatment==3 | treatment==6), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==3) == dist_res_sq_5_mean(treatment==6) :  p=.68104 (two-tailed)
			permtest2 dist_res_sq_5_mean if period==11 & type==1 & (treatment==3 | treatment==6), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==3) == dist_res_sq_5_mean(treatment==6) :  p=.5299 (two-tailed)
			permtest2 dist_res_sq_5_mean if period==16 & type==1 & (treatment==3 | treatment==6), by(treatment)
			* Test of hypothesis Ho: dist_res_sq_5_mean(treatment==3) == dist_res_sq_5_mean(treatment==6) :  p=.67814 (two-tailed)







*****************************************
* SECTION 4.2 ATTRACTION OF THE CORE    *
*****************************************


*	HOW MANY TIMES DID COMMITTEES SELECT THE CORE-ALTERNATIVE?

		*	Exactly the core
		count if dist_core==0 & type==1 & treatment==1
		*	35 of 240 (14.58%)
		count if dist_core==0 & type==1 & treatment==3
		*	55 of 240 (22.92%)

		* Results "close to the core": 5 units around the core
		count if dist_core<=5 & type==1 & treatment==1
		* 	106 of 240 (44.17%)
		count if dist_core<=5 & type==1 & treatment==3
		* 	88 of 240 (36.67%)

		* Results "close to the core": 10 units around the core
		count if dist_core<=10 & type==1 & treatment==1
		* 	182 of 240 (75.83%)
		count if dist_core<=10 & type==1 & treatment==3
		* 	106 of 240 (44.17%)

		* Results "close to the core": 20 units around the core
		count if dist_core<=20 & type==1 & treatment==1
		* 	234 of 240 (97.50%)
		count if dist_core<=20 & type==1 & treatment==3
		* 	159 of 240 (72.92%)


* FIGURE 6
			graph bar m5_dist_core  if type==2 & marker5==1 & ( treatment==1 | treatment==3), ///
				over(treatment, relabel(1 "Core - low conflict" 2 "Core - high conflict") label(labsize(small)) gap(0) ) over(per5, relabel(1 "{bf: Periods 1-5}" 2 "{bf: Periods 6-10}" 3 "{bf: Periods 11-15}" 4 "{bf: Periods 16-20}") ) ///
				asyvars bar(1, color(gs6)) bar(2, color(black)) ///
				ytitle("{bf: Mean distance between decisions and the core}", size(medsmall)) ylabel(0 (10) 42.5) ///
				blabel(bar, size(medium) format(%9.1f)) ///
				graphregion(color(white) margin(medium)) ///
				legend(rows(2) label(1 "Core - low conflict		") label(2 "Core - high conflict") size(small) ring(0) bplacement(neast)) ///
				note("{it:Core - low conflict treatment:} H{sub:0}: Distance of decisions to core in periods 6-10 = Distance of" "decisions to core in periods 16-20: {it:p}=0.889" ///
				"{it:Core - high conflict treatment:} H{sub:0}: Distance of decisions to core in periods 6-10 = Distance of" "decisions to core in periods 16-20: {it:p}=0.668" "Both test are two-sided Fisher-Pitman permutation test for paired replicates.", size(small))

				
	* DOES DISTANCE TO THE CORE DECREASE WITHIN TREATMENTS OVER TIME?

		by treatment groupid, sort: egen m5_1_distcore = mean(dist_core) if per5==1
		by treatment groupid, sort: egen m5_2_distcore = mean(dist_core) if per5==2
		by treatment groupid, sort: egen m5_3_distcore = mean(dist_core) if per5==3
		by treatment groupid, sort: egen m5_4_distcore = mean(dist_core) if per5==4
		gsort +subjectid -period
		replace m5_2_distcore = m5_2_distcore[_n-1] if m5_2_distcore >= . 
		replace m5_3_distcore = m5_3_distcore[_n-1] if m5_3_distcore >= . 
		replace m5_4_distcore = m5_4_distcore[_n-1] if m5_4_distcore >= . 

		permtest1 m5_1_distcore = m5_2_distcore if treatment==1 & type==1 & period==1
		permtest1 m5_2_distcore = m5_3_distcore if treatment==1 & type==1 & period==1
		permtest1 m5_3_distcore = m5_4_distcore if treatment==1 & type==1 & period==1
		permtest1 m5_2_distcore = m5_4_distcore if treatment==1 & type==1 & period==1

		permtest1 m5_1_distcore = m5_2_distcore if treatment==3 & type==1 & period==1
		permtest1 m5_2_distcore = m5_3_distcore if treatment==3 & type==1 & period==1
		permtest1 m5_3_distcore = m5_4_distcore if treatment==3 & type==1 & period==1
		permtest1 m5_2_distcore = m5_4_distcore if treatment==3 & type==1 & period==1	


*  DO COMMITTEES LEAVE THE CORE (PLAYER A's IDEAL-POINT) IN TREATMENT "Core - low conflict"?

		* How many times did committees select the core?
		count if type==1 & treatment==1 & final_x==opt_x1 & final_y==opt_y1
		* 35 times

		* How often did they stick to the core?
		count if type==1 & treatment==1 & (final_x==opt_x1 & final_y==opt_y1) & sq_x==opt_x1 & sq_y==opt_y1
		* 23 times

		* How often did they leave the core?
		count if type==1 & treatment==1 & (final_x!=opt_x1 | final_y!=opt_y1) & sq_x==opt_x1 & sq_y==opt_y1
		* 10 time

		* Who was the agendasetter when committees left the core, proposal against AG's self-interest, who voted against self-interest?
		list agendasetter ag_altru1 altru_vote_a altru_vote_b altru_vote_c altru_vote_d altru_vote_e if type==1 & treatment==1 & (final_x!=opt_x1 | final_y!=opt_y1) & sq_x==opt_x1 & sq_y==opt_y1
		* 0xA, 2xB, 3xC, 0xD, 5xE | 3 proposals against agendasetter's self-interest | 7 times at least 1 voter voted against self-interest
		
		
		* How often did they select the core in period 20?
		count if type==1 & treatment==1 & (final_x==opt_x1 & final_y==opt_y1) & period==20
		* 2

		sort treatment groupid period
		list groupid period if type==1 & treatment==1 & final_x==opt_x1 & final_y==opt_y1
		* 8 committees choose the core in at least 1 period
		* 7 leave it again in later periods 



	*  DO COMMITTEES LEAVE THE CORE (PLAYER A's IDEAL-POINT) IN TREATMENT "Core - high conflict"?

		* How many times did committees select the core?
		count if type==1 & treatment==3 & final_x==opt_x1 & final_y==opt_y1
		* 55 times

		* How often did they stick to the core?
		count if type==1 & treatment==3 & (final_x==opt_x1 & final_y==opt_y1) & sq_x==opt_x1 & sq_y==opt_y1
		* 45 times

		* How often did they leave the core?
		count if type==1 & treatment==3 & (final_x!=opt_x1 | final_y!=opt_y1) & sq_x==opt_x1 & sq_y==opt_y1
		* 7 time
		
		* Who was the agendasetter when committees left the core, proposal against AG's self-interest, who voted against self-interest?
		list agendasetter ag_altru1 altru_vote_a altru_vote_b altru_vote_c altru_vote_d altru_vote_e if type==1 & treatment==3 & (final_x!=opt_x1 | final_y!=opt_y1) & sq_x==opt_x1 & sq_y==opt_y1
		* 1xA, 3xB, 1xC, 2xD, 0xE | 4 proposals against agendasetter's self-interest | 6 times at least 1 voter voted against self-interest
		
		* Did A vote against her interest?
		list vote_a_alt if type==1 & treatment==3 & (final_x!=opt_x1 | final_y!=opt_y1) & sq_x==opt_x1 & sq_y==opt_y1
		* 2 x yes, 5 x no
		
		* How often did they select the core in period 20?
		count if type==1 & treatment==3 & (final_x==opt_x1 & final_y==opt_y1) & period==20
		* 3

		sort treatment groupid period
		list groupid period if type==1 & treatment==3 & final_x==opt_x1 & final_y==opt_y1
		* 7 committees choose the core in at least 1 period
		* 5 leave it again in later periods 


*	DOES MEAN OUTCOME DIFFER FROM THE CORE?
	*	Coordinates of core: x=39	y=68

		permtest1 m20_fin_x = core_x if treatment==1 & type==1 & period==1
		*	Test of hypothesis Ho: m20_fin_x==core_x  : p = .00537109

		permtest1 m20_fin_y = core_y if treatment==1 & type==1 & period==1
		*	Test of hypothesis Ho: m20_fin_y==core_y  : p = .12402344


		permtest1 m20_fin_x = core_x if treatment==3 & type==1 & period==1
		*	Test of hypothesis Ho: m20_fin_x==core_x  : p = .02148438

		permtest1 m20_fin_y = core_y if treatment==3 & type==1 & period==1
		*	Test of hypothesis Ho: m20_fin_y==core_y  : p = .20800781

	*ANSWER: Significant difference on the x-coordinate, no difference on the y-coordinate


	
	
	
*****************************************
* SECTION 4.3 INDIVIDUAL BEHAVIOR       *
*****************************************

* FIGURE 7
			gen order =.
			replace order = 1 if treatment==1
			replace order = 2 if treatment==4
			replace order = 3 if treatment==3
			replace order = 4 if treatment==6
			graph bar dist_dec_ag_opt_5_mean  if type==2 & marker5==1, ///
				over(treatment, sort(order) relabel(1 "Core" 2 "Empty core") label(labsize(small)) gap(0) ) over(per5, relabel(1 "{bf:Periods 1-5}" 2 "{bf:Periods 6-10}" 3 "{bf:Periods 11-15}" 4 "{bf:Periods 16-20}") ) ///
				asyvars bar(1, color(gs4)) bar(2, color(black)) bar(3, color(gs10)) bar(4, color(gs6)) ///
				ytitle("{bf: Mean distance between decision of agenda}" "{bf:setter and Romer-Rosenthal proposal}", size(medsmall)) ylabel(0 (10) 38) ///
				blabel(bar, format(%9.1f)) ///
				graphregion(color(white) margin(medium)) ///
				legend(rows(2) label(1 "Core - low conflict		") label(3 "Empty core - low conflict") label(2 "Core - high conflict		") label(4 "Empty core - high conflict")size(small) ring(0) bplacement(neast))
				drop order


* Average distance between agenda setter decision and Romer-Rosenthal prediction
		bys treatment: sum dist_dec_ag_opt if type==1	
		bys treatment per5: sum dist_dec_ag_opt if type==1
		
			/*
			Period 1-20		1-5	6-10 11-15 16-20
			
			-> treatment = Core, low conflict 
					5.8		5.2 5.7 5.1 7.2
			-> treatment = Core, high conflict
					23.0	20.5 29.7 17.3 24.5
			-> treatment = No core, low conflict
					6.6		6.0 7.9 6.3 6.1
			-> treatment = No core, high conflict
					21.1	23.2 14.6 26.6 19.8
			*/


*** HOW MUCH DO PROPOSERS PROFIT - VALUE OF AGENDA SETTING POWER
	
	gsort +subjectid period
	generate before_agendasetter = agendasetter[_n-1]
	generate same_agendasetter = 0
	replace same_agendasetter = 1 if period>1 & before_agendasetter==agendasetter
	drop before_agendasetter
	
	generate profit_before = profit[_n-1]
	replace profit_before = . if period==1
	generate change_profit= profit-profit_before
	
	bys treatment: sum change_profit if proposer==1
	bys treatment: sum change_profit if proposer==1 & same_agendasetter==0
	/*
			Period 1-20		
			
			-> treatment = Core, low conflict 
					50.1	
			-> treatment = Core, high conflict
					118.6	
			-> treatment = No core, low conflict
					77.3		
			-> treatment = No core, high conflict
					163.3	
			*/
	
	bys treatment: sum change_profit if proposer==1 & same_agendasetter==1
	sum change_profit if proposer==1
	sum change_profit if proposer==1 & same_agendasetter==0
	sum change_profit if proposer==1 & same_agendasetter==1


	
* How often did agenda setters propose a point offering them LESS than SQ (by type)?
		bys treatment: count if ag_prop_points<ag_sq_points & type==1
		bys treatment agendasetter: count if ag_prop_points<ag_sq_points & type==1
		
		/*
			Player	ALL 				A B C D E
			
			-> treatment = Core, low conflict 
					73/240 (30.4%)		18/46 11/42 16/46 14/48 14/58
			-> treatment = Core, high conflict
					68/240 (28.3%)		22/48 14/49 14/50 12/54 6/39
			-> treatment = No core, low conflict
					52/240 (21.7%)		18/50 8/48 8/47 8/46 10/49
			-> treatment = No core, high conflict
					47/240 (19.6%)		14/49 10/46 10/41 8/51 5/53
			
			Group behavior is mostly driven by agenda setters! Non-egoistic behavior much more likely in role of agendasetter in comparision to role of voter.
			*/

* How often did agenda setters propose points offering them MORE points in comparison to Romer-Rosenthal prediction?
		bys treatment : count if ag_askformore==1 & type==1
		bys treatment agendasetter: count if ag_askformore==1 & type==1
		
		/*
			Player	ALL			A B C D E
			
			-> treatment = Core, low conflict 
					47/240		0/46 12/42 8/46 5/48 22/58
			-> treatment = Core, high conflict
					51/240		0/48 8/49 10/50 15/54 18/39
			-> treatment = No core, low conflict
					13/240		3/50 1/48 2/47 4/46 3/49
			-> treatment = No core, high conflict
					40/240		0/49 7/46 4/41 6/51 23/53
			
			Meaning of this statistic is unclear. Player A in core treatments cannot propose a point offering her more points than Romer-Rosenthal prediction
			
			*/
			
			
* How often did subjects vote in line and against self-interest (by type)?
		bys treatment: tab altru_vote
		bys treatment type: tab altru_vote
		/*
			Player	ALL 				A B C D E
			
			-> treatment = Core, low conflict 
					643/77 (10.7%)		139/11	132/16	120/25	124/18	128/7
			-> treatment = Core, high conflict
					695/77 (10.0%)		143/16	149/5	128/23	136/12	139/21
			-> treatment = No core, low conflict
					704/80 (10.2%)		132/29	148/8	148/8	136/20	140/15
			-> treatment = No core, high conflict
					750/62	(7.6%)		156/9	154/13	160/10	134/23	146/7
			
			*/
			
			
**********************************************
** REGRESSSION ANALYSES 			**********
**********************************************
	
	xtset subjectid period
	replace prop_winset= . if prop_winset==-99
	
	* MODEL 1 - Inequality measure compares standard deviation of proposal and SQ				
	xtprobit win i.prop_winset i.avg_prop_higher i.prop_more_equal i.treatment if win<2  & type==1, vce(robust)
	
	* MODEL 2 - Inquality measures compare lowest payoff and highest payoff in proposal and SQ
	xtprobit win i.prop_winset  i.avg_prop_higher i.worst_prop_higher i.best_prop_higher i.treatment if win<2  & type==1 , vce(robust)
